package rytkonen.topi.maps;



import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

import com.google.android.gms.maps.model.LatLng;

import static android.content.ContentValues.TAG;

public class Database extends SQLiteOpenHelper  {

    /**
     * Setting up Database
     */
    public static final String DATABASE_NAME = "places.db";
    public static final String TABLE_NAME = "places_table";
    public static final String COL1 = "ID";
    public static final String COL2 = "ITEM_ID";
    public static final String COL3 = "LAT";
    public static final String COL4 = "LNG";
    public static final String COL5 = "COMMENT";


    public Database(Context context) {
        super(context, DATABASE_NAME, null, 1);
    }


    @Override
    public void onCreate(SQLiteDatabase db) {
        String createTable = "CREATE TABLE " + TABLE_NAME + " (ID INTEGER PRIMARY KEY AUTOINCREMENT, " +
                " ITEM_ID INTEGER," +
                " LAT DOUBLE," +
                " LNG DOUBLE,"+
                " COMMENT TEXT)";

        db.execSQL(createTable);

    }


    @Override
    public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
        db.execSQL("DROP TABLE IF EXISTS " + TABLE_NAME);
        onCreate(db);
    }

    /**
     * Insersts data to table
     * @param item_id id of item(like blueberry)
     * @param lat Latitude of inserted item
     * @param lng Longitude of inserted item
     * @param comment String what is arond of item
     * @return
     */
    public boolean addData(Integer item_id, Double lat, Double lng, String comment){
        Log.i(TAG, "addData: object inserted");
        SQLiteDatabase db = this.getWritableDatabase();
        ContentValues contentValues = new ContentValues();
        contentValues.put(COL2, item_id);
        contentValues.put(COL3, lat);
        contentValues.put(COL4, lng);
        contentValues.put(COL5, comment);
        long result  = db.insert(TABLE_NAME, null, contentValues);
        if(result == -1){
            return false;
        }else{
            return true;
        }
    }

    /**
     * Shows data to user
     * @return
     */
    public Cursor showData(){
        SQLiteDatabase db = this.getWritableDatabase();
        Cursor data = db.rawQuery("SELECT * FROM " + TABLE_NAME, null);
        //db.execSQL("delete  from "+ TABLE_NAME);
        return data;
    }

    /**
     * Gets items id
     * @return
     */
    public Cursor GetitemID(){
        SQLiteDatabase db = this.getWritableDatabase();
        Cursor data = db.rawQuery("SELECT "+COL2+ " FROM " +TABLE_NAME, null);

        return data;
    }

    /**
     * Gets items Latitude
     * @return
     */
    public Cursor GetLat(){
        SQLiteDatabase db = this.getWritableDatabase();
        Cursor data = db.rawQuery("SELECT "+COL3+ " FROM " +TABLE_NAME, null);

        return data;
    }

    /**
     * Gets items longitude
     * @return
     */
    public Cursor GetLng(){
        SQLiteDatabase db = this.getWritableDatabase();
        Cursor data = db.rawQuery("SELECT "+COL4+ " FROM " +TABLE_NAME, null);

        return data;
    }

    /**
     * Gets items comment
     * @return
     */
    public Cursor GetComment(){
        SQLiteDatabase db = this.getWritableDatabase();
        Cursor data = db.rawQuery("SELECT "+COL5+ " FROM " +TABLE_NAME, null);

        return data;
    }

    /**
     * Gets items ItemID
     * @param lat latitude
     * @param lng longitude
     * @return
     */
    public Cursor GetLatLng(Double lat, Double lng){
        SQLiteDatabase db = this.getWritableDatabase();
        Cursor data = db.rawQuery("SELECT "+COL2+ " FROM " + TABLE_NAME + " WHERE " +COL3 + "='" + lat + "'" + " AND " + COL4 + "='" + lng + "'", null);
        return data;
    }

    /**
     * Gets ID of item
     * @param lat latitude
     * @param lng Longitude
     * @return
     */
    public Cursor getid(Double lat, Double lng){
        Log.i(TAG, "getid: Start");
        SQLiteDatabase db = this.getWritableDatabase();
        Cursor data = db.rawQuery(" SELECT " + COL1 + " FROM " + TABLE_NAME + " WHERE " + COL3 + "='" + lat + "'" + " AND " + COL4 + "='" + lng + "'", null);
        Log.i(TAG, "getid: End");
        return data;
    }

    /**
     * Deletes data using id
     * @param id id of row
     * @return
     */
    public Integer deleteData(String id){
        Log.i(TAG, "Database: deleteData initiated");
        SQLiteDatabase db = this.getWritableDatabase();
        return db.delete(TABLE_NAME, "ID = ?", new String[] {id});

    }




}
